@@ -32,13 +32,13 @@ class FullUrlHtmlParser(UTF8HTMLParser):
         >>> p = FullUrlHtmlParser('http://www.example.com')
         >>> p.feed(u'<a href="sample.html">')
         >>> p.get_value()
-        u"<a href='http://www.example.com/sample.html'>"
+        u'<a href="http://www.example.com/sample.html">'
 
     Non-external resource are ignored::
         >>> p = FullUrlHtmlParser('http://www.example.com')
         >>> p.feed('<a href="mailto:me@example.com">')
         >>> p.get_value()
-        u"<a href='mailto:me@example.com'>"
+        u'<a href="mailto:me@example.com">'
 
     A more complex example::
     >>> p.reset()
@@ -54,10 +54,10 @@ class FullUrlHtmlParser(UTF8HTMLParser):
     ... More ..........""")
     >>> print p.get_value() #doctest: +NORMALIZE_WHITESPACE
     <!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
-    <a href='http://www.example.com/test'>foo</a>
-    <img src='http://www.example.com/invalid_html'>
-    <img src='http://www.example.com/img.pic'/> some random text.
-    <a href='http://www.google.ca'>bar</a>
+    <a href="http://www.example.com/test">foo</a>
+    <img src="http://www.example.com/invalid_html">
+    <img src="http://www.example.com/img.pic"/> some random text.
+    <a href="http://www.google.ca">bar</a>
     &raquo;&#126;
     <?echo 'yo'>
     <!--  foo bar < > yeah  -->
@@ -68,16 +68,6 @@ class FullUrlHtmlParser(UTF8HTMLParser):
         UTF8HTMLParser.__init__(self)
         self.base_url = base_url.rstrip('/')
 
-    @staticmethod
-    def html_attrs(attrs):
-        '''
-        >>> FullUrlHtmlParser.html_attrs((('src', 'pic.jpg'), ('alt', 'pic')))
-        u"src='pic.jpg' alt='pic'"
-        >>> FullUrlHtmlParser.html_attrs(list())
-        u''
-        '''
-        return u' '.join(u'%s=\'%s\'' % (k, v) for k, v in attrs)
-
     def make_full_url(self, attr, attrs):
         '''
         Change ``attrs[attr]`` from a relative URI to an absolute URI.
@@ -98,11 +88,10 @@ class FullUrlHtmlParser(UTF8HTMLParser):
         '''
         >>> p = FullUrlHtmlParser('http://www.example.com')
         >>> p.rewrite_tag('a', (('href', 'foo'),))
-        u"<a href='http://www.example.com/foo'>"
+        u'<a href="http://www.example.com/foo">'
         >>> p.rewrite_tag('img', (('src', 'pic.png'), ('width', '100')))
-        u"<img src='http://www.example.com/pic.png' width='100'>"
+        u'<img src="http://www.example.com/pic.png" width="100">'
         '''
-
         if attrs:
             if tag == u'a':
                 attrs = self.make_full_url(u'href', attrs)
@@ -139,9 +128,9 @@ def html_full_url(base_url, text):
       *absolute* URI.
 
     >>> html_full_url('http://example.com', '<a href="test.html">')
-    u"<a href='http://example.com/test.html'>"
+    u'<a href="http://example.com/test.html">'
     >>> html_full_url('http://example.com', '<img src="test.png">')
-    u"<img src='http://example.com/test.png'>"
+    u'<img src="http://example.com/test.png">'
     '''
     p = FullUrlHtmlParser(base_url)
     p.feed(text)
