@@ -4,8 +4,7 @@ import codecs
 import locale
 import logging
 import datetime
-import unicodedata
-from os import stat
+from os import stat, path
 from urllib import quote
 
 try:
@@ -178,28 +177,45 @@ class Post(object):
         else:
             self.files = list()
 
-    # FIXME prefix & suffix param or members of the class ?
-    def url(self, prefix=''):
+    def directories(self):
+        r'''Return the list of directories where the post is stored.
+
+            >>> from StringIO import StringIO
+            >>> p = Post(StringIO('title: test\ndate: 2009-9-25\n\ntest'))
+            >>> p.directories()
+            ('2009', '9', '25')
         '''
-        >>> file_content = """title: test
-        ... date: 2008-1-1
-        ...
-        ... test"""
-        >>> from StringIO import StringIO
-        >>> Post(StringIO(file_content)).url()
-        '2008/1/1/test.html'
-        >>> Post(StringIO(file_content)).url('prefix/')
-        'prefix/2008/1/1/test.html'
-        >>> file_content = """title: Weird @!% filename
-        ... date: 2008-1-1
-        ...
-        ... test"""
-        >>> Post(StringIO(file_content)).url()
-        '2008/1/1/Weird_%40%21%25_filename.html'
+        return (str(self.date.year),
+                str(self.date.month),
+                str(self.date.day))
+
+    def filename(self):
+        r'''Return the filename where to post should be stored.
+
+            >>> from StringIO import StringIO
+            >>> p = Post(StringIO('title: test\ndate: 2009-9-25\n\ntest'))
+            >>> p.filename()
+            '2009/9/25/test.html'
         '''
-        return '%s%d/%d/%d/%s.html' % \
-            (prefix, self.date.year, self.date.month, self.date.day,
-             quote(self.slug))
+        return path.join(*(self.directories() + (self.slug + '.html',)))
+
+    def url(self):
+        r'''Returns url of the post.
+
+            >>> file_content = """title: test
+            ... date: 2008-1-1
+            ...
+            ... test"""
+            >>> from StringIO import StringIO
+            >>> Post(StringIO(file_content)).url()
+            '2008/1/1/test.html'
+
+        The url is URL-quoted:
+
+            >>> Post(StringIO('title: @!%\ndate: 2009-10-1\n\ntest')).url()
+            '2009/10/1/%40%21%25.html'
+        '''
+        return '/'.join(self.directories() + (quote(self.slug) + '.html',))
 
     _DATE_FORMAT_LIST = ('%Y-%m-%d', '%y-%m-%d')
 
