@@ -25,7 +25,7 @@ def _check_duplicated(p, posts):
                 break
         raise IOError('%s, there is already a post '
                       'with this title and date (%s)' % \
-                      (filename, duplicated_post.get_filename()))
+                      (p.get_filename(), duplicated_post.get_filename()))
 
 def load_posts(source_dir, config):
     posts = set()
@@ -51,10 +51,7 @@ def load_posts(source_dir, config):
 def generate_post_html(post_list, output_dir, post_tmpl, config):
     for post in post_list:
         logging.debug('Generating HTML file for %r', post)
-        dir = os.path.join(output_dir,
-                           str(post.date.year),
-                           str(post.date.month),
-                           str(post.date.day))
+        dir = os.path.join(output_dir, *post.directories())
         if not os.path.isdir(dir):
             logging.debug('Creating directory %s', dir)
             os.makedirs(dir)
@@ -66,7 +63,7 @@ def generate_post_html(post_list, output_dir, post_tmpl, config):
                            content=html_full_url(top_dir,
                                                  post.get_html()),
                            top_dir=top_dir))
-        _write_file(os.path.join(dir, post.slug + '.html'),
+        _write_file(os.path.join(output_dir, post.filename()),
                     config.get('encoding'),
                     post_tmpl.render(**params))
 
